pub enum CanonicalInteger {
Signed(i64),
Unsigned(u64),
}Expand description
An integer parsed without passing through binary64.
During JSON parsing, tokens with a leading minus sign use the signed domain
and all other integer tokens use the unsigned domain. The public variants
also allow direct construction with any i64 or u64; their common values
intentionally have the same TCV1 decimal encoding. Lexical -0 parses as
signed zero and has the same TCV1 encoding as unsigned zero.
Variants