pub enum PortableRefitMode {
Full,
Transfer,
Finetune,
}Expand description
The only retrain mode currently representable by the portable archive
boundary. Transfer and Finetune are explicit values so a future wire
cannot accidentally be interpreted as Full by an older caller.
Variants