pub struct CrossFoldValidation {
pub reports: Vec<RegressionMetricReport>,
pub oof_averages: Vec<OofAverageBlock>,
}Expand description
The output of cross_fold_validation_reports: the scalar cross-fold OOF average reports (one per
producer, fold_id = "avg") plus — purely additively — the per-sample OOF average block + y_true
each report was computed from. reports is byte-identical to the historical Vec return; callers
that only need the scalars read reports and ignore oof_averages.
Fields
reports: Vec<RegressionMetricReport>oof_averages: Vec<OofAverageBlock>Trait Implementations
Sourceimpl Clone for CrossFoldValidation
impl Clone for CrossFoldValidation
Sourcefn clone(&self) -> CrossFoldValidation
fn clone(&self) -> CrossFoldValidation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CrossFoldValidation
impl Debug for CrossFoldValidation
Sourceimpl Default for CrossFoldValidation
impl Default for CrossFoldValidation
Sourcefn default() -> CrossFoldValidation
fn default() -> CrossFoldValidation
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for CrossFoldValidation
impl PartialEq for CrossFoldValidation
Sourcefn eq(&self, other: &CrossFoldValidation) -> bool
fn eq(&self, other: &CrossFoldValidation) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CrossFoldValidation