pub struct PortableRefitReplayOutcomeV3 {Show 17 fields
pub schema_version: u32,
pub outcome_id: String,
pub run_id: RunId,
pub source_package_fingerprint: String,
pub source_refit_outcome_fingerprint: String,
pub replay_request_id: String,
pub replay_request_fingerprint: String,
pub input_data_identities: Vec<ReplayDataIdentity>,
pub bundle_id: BundleId,
pub plan_id: String,
pub phase: Phase,
pub outputs: Vec<BoundTrainingOutput>,
pub explanations: Vec<ExplanationBlock>,
pub lineage: Vec<LineageRecord>,
pub warnings: Vec<String>,
pub diagnostics: BTreeMap<String, Value>,
pub outcome_fingerprint: String,
}Expand description
V3 replay evidence. This remains separate from TrainingReplayOutcome,
whose source reference proves an original CV/SELECT training outcome.
Fields
schema_version: u32outcome_id: Stringrun_id: RunIdsource_package_fingerprint: Stringsource_refit_outcome_fingerprint: Stringreplay_request_id: Stringreplay_request_fingerprint: Stringinput_data_identities: Vec<ReplayDataIdentity>bundle_id: BundleIdplan_id: Stringphase: Phaseoutputs: Vec<BoundTrainingOutput>explanations: Vec<ExplanationBlock>lineage: Vec<LineageRecord>warnings: Vec<String>diagnostics: BTreeMap<String, Value>outcome_fingerprint: StringImplementations
Sourceimpl PortableRefitReplayOutcomeV3
impl PortableRefitReplayOutcomeV3
pub fn compute_fingerprint(&self) -> Result<String, DagMlError>
Sourcepub fn from_json_for_package(
json: &str,
package: &PortableRefitPackageV3,
request: &TrainingReplayRequest,
) -> Result<PortableRefitReplayOutcomeV3, DagMlError>
pub fn from_json_for_package( json: &str, package: &PortableRefitPackageV3, request: &TrainingReplayRequest, ) -> Result<PortableRefitReplayOutcomeV3, DagMlError>
Parse replay evidence only in the presence of the exact V3 child and replay request it claims to describe. A standalone deserializer would make both source fingerprints self-attested.
pub fn validate_against( &self, package: &PortableRefitPackageV3, request: &TrainingReplayRequest, ) -> Result<(), DagMlError>