pub struct TerminalPredictionReplay<'a> {
pub plan: &'a ExecutionPlan,
pub bundle: &'a ExecutionBundle,
pub envelope: &'a ExternalDataPlanEnvelope,
pub selector: &'a TerminalPredictionSelector,
pub controllers: &'a RuntimeControllerRegistry,
pub data_provider: &'a dyn RuntimeDataProvider,
pub artifact_store: &'a dyn RuntimeArtifactStore,
}Expand description
Runtime resources for one closed terminal PREDICT replay.
This groups the borrowed execution boundary so the public API remains explicit without leaking a positional list of host/runtime dependencies.
Fields
plan: &'a ExecutionPlanbundle: &'a ExecutionBundleenvelope: &'a ExternalDataPlanEnvelopeselector: &'a TerminalPredictionSelectorcontrollers: &'a RuntimeControllerRegistrydata_provider: &'a dyn RuntimeDataProviderartifact_store: &'a dyn RuntimeArtifactStoreAuto Trait Implementations
impl<'a> !RefUnwindSafe for TerminalPredictionReplay<'a>
impl<'a> !Send for TerminalPredictionReplay<'a>
impl<'a> !Sync for TerminalPredictionReplay<'a>
impl<'a> !UnwindSafe for TerminalPredictionReplay<'a>
impl<'a> Freeze for TerminalPredictionReplay<'a>
impl<'a> Unpin for TerminalPredictionReplay<'a>
impl<'a> UnsafeUnpin for TerminalPredictionReplay<'a>